@@ -104,7 +104,7 @@ class Interaktion:
             if "trigger_weiter" in interaktion_dict.keys():
                 trigger_weiter = interaktion_dict["trigger_weiter"]
             else:
-                trigger_weiter = [("Liste", "Weiter")]
+                trigger_weiter = [("Liste", "Weiter"), ("Liste", "Ja"), ("Rasa", "weiter"), ("Rasa", "ja")]
                 print(
                     "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
 
@@ -159,7 +159,7 @@ class Interaktion:
             if "trigger_weiter" in interaktion_dict.keys():
                 trigger_weiter = interaktion_dict["trigger_weiter"]
             else:
-                trigger_weiter = [("Liste", "Weiter")]
+                trigger_weiter = [("Liste", "Weiter"), ("Liste", "Ja"), ("Rasa", "weiter"), ("Rasa", "ja")]
                 print(
                     "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
 
@@ -182,14 +182,14 @@ class Interaktion:
             for aktion, aktion_list in interaktion_dict.items():
                 if aktion.startswith("antwort_"):
                     actions["{}_{}".format(poi_name, aktion)] = [{"type": "function",
-                                                                  "func": "loop_list",
+                                                                  "func": "listenfrageActions:loop_list",
                                                                   "key": poi_name,
                                                                   "value": aktion.replace("antwort_", ""),
                                                                   "doppelte_antwort": readActions(interaktion_dict["doppelte Antwort"], messanger=messanger, asset_url=asset_url)}]\
                         + readActions(aktion_list, messanger=messanger, asset_url=asset_url) \
                         + readActions(interaktion_dict["richtig Antwort"], messanger=messanger, asset_url=asset_url) \
                         + [{"type": "function",
-                            "func": "loop_list_fertig",
+                            "func": "listenfrageActions:loop_list_fertig",
                             "key": poi_name,
                             "answer_id_list": answer_id_list,
                             "fertig_antwort": readActions(interaktion_dict["fertig Antwort"], messanger=messanger, asset_url=asset_url)}]
@@ -205,7 +205,7 @@ class Interaktion:
                         states["{}_AUFLOESUNG".format(poi_name.upper())] += readTriggers(
                             aktion_list, "{}_{}_re".format(poi_name, aktion.replace("trigger_", "antwort_")))
 
-            actions["{}_aufloesung".format(poi_name)] = [{"type": "function", "func": "eval_list", "answer_id_name_list": answer_id_name_list, "poi": poi_name, "response_text": interaktion_dict["response_text"][0][1]}]\
+            actions["{}_aufloesung".format(poi_name)] = [{"type": "function", "func": "listenfrageActions:eval_list", "answer_id_name_list": answer_id_name_list, "poi": poi_name, "response_text": interaktion_dict["response_text"][0][1]}]\
                 + readActions(interaktion_dict["Aufloesung"], messanger=messanger, asset_url=asset_url) \
                 + readActions([("Return", "{}_AUFLOESUNG".format(poi_name.upper()))], messanger=messanger, asset_url=asset_url)
 
@@ -220,7 +220,7 @@ class Interaktion:
             if "trigger_weiter" in interaktion_dict.keys():
                 trigger_weiter = interaktion_dict["trigger_weiter"]
             else:
-                trigger_weiter = [("Liste", "Weiter")]
+                trigger_weiter = [("Liste", "Weiter"), ("Liste", "Ja"), ("Rasa", "weiter"), ("Rasa", "ja")]
                 print(
                     "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
 
@@ -235,7 +235,8 @@ class Interaktion:
 
             actions["{}_aufloesung".format(poi_name)] = readActions(
                 interaktion_dict["Aufloesung"] + [("Return", "{}_AUFLOESUNG".format(poi_name.upper()))], messanger=messanger, asset_url=asset_url)
-
+            print(interaktion_dict)
+            print(interaktion_dict["Typ"])
             states["{}_FRAGE".format(poi_name.upper())] = readTriggers([("Liste", "Weiter")], next_interaktion) \
                 + readTriggers([("Liste", "Nein")], next_interaktion) \
                 + readTriggers(interaktion_dict["Typ"], "{}_aufloesung".format(poi_name)) \
@@ -246,7 +247,7 @@ class Interaktion:
             if "trigger_weiter" in interaktion_dict.keys():
                 trigger_weiter = interaktion_dict["trigger_weiter"]
             else:
-                trigger_weiter = [("Liste", "Weiter")]
+                trigger_weiter = [("Liste", "Weiter"), ("Liste", "Ja"), ("Rasa", "weiter"), ("Rasa", "ja")]
                 print(
                     "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
 
@@ -267,7 +268,7 @@ class Interaktion:
             if "trigger_weiter" in interaktion_dict.keys():
                 trigger_weiter = interaktion_dict["trigger_weiter"]
             else:
-                trigger_weiter = [("Liste", "Weiter"), ("Liste", "Nein")]
+                trigger_weiter = [("Liste", "Weiter"), ("Liste", "Ja"), ("Liste", "Nein"), ("Rasa", "weiter"), ("Rasa", "ja"), ("Rasa", "nein")]
                 print(
                     "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
 
@@ -284,7 +285,7 @@ class Interaktion:
             if "trigger_weiter" in interaktion_dict.keys():
                 trigger_weiter = interaktion_dict["trigger_weiter"]
             else:
-                trigger_weiter = [("Liste", "Weiter")]
+                trigger_weiter = [("Liste", "Weiter"), ("Liste", "Ja"), ("Rasa", "weiter"), ("Rasa", "ja")]
                 print(
                     "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
 
@@ -309,7 +310,7 @@ class Interaktion:
             if "trigger_weiter" in interaktion_dict.keys():
                 trigger_weiter = interaktion_dict["trigger_weiter"]
             else:
-                trigger_weiter = [("Liste", "Weiter")]
+                trigger_weiter = [("Liste", "Weiter"), ("Liste", "Ja"), ("Rasa", "weiter"), ("Rasa", "ja")]
                 print(
                     "Info: {} hat keinen Trigger weiter - der Standardwert wird benutzt.".format(poi_name))
 
